summaryrefslogtreecommitdiff
path: root/public/fpdf_sysfontinfo.h
diff options
context:
space:
mode:
Diffstat (limited to 'public/fpdf_sysfontinfo.h')
-rw-r--r--public/fpdf_sysfontinfo.h17
1 files changed, 15 insertions, 2 deletions
diff --git a/public/fpdf_sysfontinfo.h b/public/fpdf_sysfontinfo.h
index c2da74b70b..d75aa19629 100644
--- a/public/fpdf_sysfontinfo.h
+++ b/public/fpdf_sysfontinfo.h
@@ -290,11 +290,24 @@ DLLEXPORT void STDCALL FPDF_SetSystemFontInfo(FPDF_SYSFONTINFO* pFontInfo);
* Pointer to a FPDF_SYSFONTINFO structure describing the default
*interface.
* Or NULL if the platform doesn't have a default interface.
* Application should call FPDF_FreeMemory to free the returned
*pointer.
**/
DLLEXPORT FPDF_SYSFONTINFO* STDCALL FPDF_GetDefaultSystemFontInfo();
+/**
+ * Function: FPDF_FreeDefaultSystemFontInfo
+ * Free a default system font info interface
+ * Comments:
+ * This function should be called on the output from
+ *FPDF_SetSystemFontInfo once it is no longer needed by the client.
+ * Parameters:
+ * pFontInfo - Pointer to a FPDF_SYSFONTINFO structure
+ * Return Value:
+ * None
+ **/
+DLLEXPORT void FPDF_FreeDefaultSystemFontInfo(FPDF_SYSFONTINFO* pFontInfo);
+
#ifdef __cplusplus
}
#endif
@@ -290,11 +290,24 @@ DLLEXPORT void STDCALL FPDF_SetSystemFontInfo(FPDF_SYSFONTINFO* pFontInfo);
*interface.
* Or NULL if the platform doesn't have a default interface.
- * Application should call FPDF_FreeMemory to free the returned
- *pointer.
+ * Application should call FPDF_FreeDefaultSystemFontInfo to free the
+ *returned pointer.
**/
DLLEXPORT FPDF_SYSFONTINFO* STDCALL FPDF_GetDefaultSystemFontInfo();